pub(crate) struct ContextChain<S, R = BrigadierRuntime>where
R: CommandRuntime<S>,{
contexts: Arc<[Arc<CommandContext<S, R>>]>,
position: usize,
}Expand description
A flattened sequence of redirect contexts followed by one executable context.
Fields
contexts: Arc<[Arc<CommandContext<S, R>>]>position: usizeImplementations
Sourceimpl<S, R> ContextChain<S, R>where
R: CommandRuntime<S>,
impl<S, R> ContextChain<S, R>where
R: CommandRuntime<S>,
pub(super) fn try_flatten(root: Arc<CommandContext<S, R>>) -> Option<Self>
Sourcepub(crate) fn stage(&self) -> ContextChainStage
pub(crate) fn stage(&self) -> ContextChainStage
Returns the kind of work represented by the current stage.
Sourcepub(crate) fn top_context(&self) -> &CommandContext<S, R>
pub(crate) fn top_context(&self) -> &CommandContext<S, R>
Returns the parsed context at the current stage.
Sourcepub(crate) fn next_stage(&self) -> Option<Self>
pub(crate) fn next_stage(&self) -> Option<Self>
Advances to the next redirect or executable stage.
Sourceimpl<S> ContextChain<S, BrigadierRuntime>
impl<S> ContextChain<S, BrigadierRuntime>
Sourcepub(crate) fn run_modifier(
&self,
source: Arc<S>,
consumer: &dyn Fn(&CommandContext<S, BrigadierRuntime>, bool, i32),
forked: bool,
) -> Result<Vec<Arc<S>>, CommandSyntaxError>
pub(crate) fn run_modifier( &self, source: Arc<S>, consumer: &dyn Fn(&CommandContext<S, BrigadierRuntime>, bool, i32), forked: bool, ) -> Result<Vec<Arc<S>>, CommandSyntaxError>
Applies the current stage’s source modifier.
Sourcepub(crate) fn run_executable(
&self,
source: Arc<S>,
consumer: &dyn Fn(&CommandContext<S, BrigadierRuntime>, bool, i32),
forked: bool,
) -> Result<i32, CommandSyntaxError>
pub(crate) fn run_executable( &self, source: Arc<S>, consumer: &dyn Fn(&CommandContext<S, BrigadierRuntime>, bool, i32), forked: bool, ) -> Result<i32, CommandSyntaxError>
Runs the current stage’s terminal command.
Sourcepub(crate) fn execute_all(
&self,
source: S,
consumer: &dyn Fn(&CommandContext<S, BrigadierRuntime>, bool, i32),
) -> Result<i32, CommandSyntaxError>
pub(crate) fn execute_all( &self, source: S, consumer: &dyn Fn(&CommandContext<S, BrigadierRuntime>, bool, i32), ) -> Result<i32, CommandSyntaxError>
Executes the complete chain with Brigadier’s synchronous semantics.